@@ -150,16 +150,22 @@ typedef enum {
  * @E_CONTENT_EDITOR_INSERT_REPLACE_ALL:
  * @E_CONTENT_EDITOR_INSERT_TEXT_HTML:
  * @E_CONTENT_EDITOR_INSERT_TEXT_PLAIN:
+ * @E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE: Set when should convert plain text into &lt;pre&gt; instead of &lt;div&gt;. Since 3.40
+ * @E_CONTENT_EDITOR_INSERT_CLEANUP_SIGNATURE_ID: Set when should cleanup signature ID in the body. Since 3.42
+ * @E_CONTENT_EDITOR_INSERT_FROM_PLAIN_TEXT: Set when the HTML source is a plain text editor. Since: 3.48
  *
  * Since: 3.22
  **/
 typedef enum {
-	E_CONTENT_EDITOR_INSERT_NONE		= 0,
-	E_CONTENT_EDITOR_INSERT_CONVERT		= 1 << 0,
-	E_CONTENT_EDITOR_INSERT_QUOTE_CONTENT	= 1 << 1,
-	E_CONTENT_EDITOR_INSERT_REPLACE_ALL	= 1 << 2,
-	E_CONTENT_EDITOR_INSERT_TEXT_HTML	= 1 << 3,
-	E_CONTENT_EDITOR_INSERT_TEXT_PLAIN	= 1 << 4,
+	E_CONTENT_EDITOR_INSERT_NONE			= 0,
+	E_CONTENT_EDITOR_INSERT_CONVERT			= 1 << 0,
+	E_CONTENT_EDITOR_INSERT_QUOTE_CONTENT		= 1 << 1,
+	E_CONTENT_EDITOR_INSERT_REPLACE_ALL		= 1 << 2,
+	E_CONTENT_EDITOR_INSERT_TEXT_HTML		= 1 << 3,
+	E_CONTENT_EDITOR_INSERT_TEXT_PLAIN		= 1 << 4,
+	E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE	= 1 << 5,
+	E_CONTENT_EDITOR_INSERT_CLEANUP_SIGNATURE_ID	= 1 << 6,
+	E_CONTENT_EDITOR_INSERT_FROM_PLAIN_TEXT 	= 1 << 7
 } EContentEditorInsertContentFlags;
 
 /**
@@ -521,6 +527,28 @@ typedef enum {
 	E_CONTENT_EDITOR_FIND_WRAP_AROUND	= 1 << 4
 } EContentEditorFindFlags;
 
+/**
+ * EContentEditorMode:
+ * @E_CONTENT_EDITOR_MODE_UNKNOWN: unknown mode
+ * @E_CONTENT_EDITOR_MODE_PLAIN_TEXT: plain text, expects export as text/plain
+ * @E_CONTENT_EDITOR_MODE_HTML: HTML, expects export as text/html
+ * @E_CONTENT_EDITOR_MODE_MARKDOWN: markdown, expects export as text/markdown
+ * @E_CONTENT_EDITOR_MODE_MARKDOWN_PLAIN_TEXT: markdown, expects export as text/plain
+ * @E_CONTENT_EDITOR_MODE_MARKDOWN_HTML: markdown, expects export as text/html
+ *
+ * Editing mode of a content editor.
+ *
+ * Since: 3.44
+ **/
+typedef enum {
+	E_CONTENT_EDITOR_MODE_UNKNOWN = -1,
+	E_CONTENT_EDITOR_MODE_PLAIN_TEXT,
+	E_CONTENT_EDITOR_MODE_HTML,
+	E_CONTENT_EDITOR_MODE_MARKDOWN,
+	E_CONTENT_EDITOR_MODE_MARKDOWN_PLAIN_TEXT,
+	E_CONTENT_EDITOR_MODE_MARKDOWN_HTML
+} EContentEditorMode;
+
 /**
  * EUndoRedoState:
  * @E_UNDO_REDO_STATE_NONE: Cannot undo, neither redo.
@@ -616,6 +644,45 @@ typedef enum {
  **/
 #define E_CONFIG_LOOKUP_RESULT_LAST_KIND E_CONFIG_LOOKUP_RESULT_TASK_LIST
 
+/**
+ * EMarkdownHTMLToTextFlags:
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE: no flag set
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT: disallow any HTML, save in pure plain text
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS: enable composer quirks to post-process the text
+ * @E_MARKDOWN_HTML_TO_TEXT_FLAG_SIGNIFICANT_NL: whether new lines in the text are significant,
+ *    aka whether they work the same as the &lt;br&gt; elements. Since: 3.48
+ *
+ * Flags used in e_markdown_util_html_to_text().
+ *
+ * Since: 3.44
+ **/
+typedef enum { /*< flags >*/
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_NONE		= 0,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_PLAIN_TEXT		= 1 << 0,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_COMPOSER_QUIRKS	= 1 << 1,
+	E_MARKDOWN_HTML_TO_TEXT_FLAG_SIGNIFICANT_NL	= 1 << 2
+} EMarkdownHTMLToTextFlags;
+
+/**
+ * EMarkdownTextToHTMLFlags:
+ * @E_MARKDOWN_TEXT_TO_HTML_FLAG_NONE: no flag set
+ * @E_MARKDOWN_TEXT_TO_HTML_FLAG_INCLUDE_SOURCEPOS: include source position in the generated HTML
+ *
+ * Flags used in e_markdown_util_text_to_html_full().
+ *
+ * Since: 3.48
+ **/
+typedef enum { /*< flags >*/
+	E_MARKDOWN_TEXT_TO_HTML_FLAG_NONE		= 0,
+	E_MARKDOWN_TEXT_TO_HTML_FLAG_INCLUDE_SOURCEPOS	= 1 << 0
+} EMarkdownTextToHTMLFlags;
+
+typedef enum {
+	E_TOOLBAR_ICON_SIZE_DEFAULT	= 0,
+	E_TOOLBAR_ICON_SIZE_SMALL	= 1,
+	E_TOOLBAR_ICON_SIZE_LARGE	= 2
+} EToolbarIconSize;
+
 G_END_DECLS
 
 #endif /* E_UTIL_ENUMS_H */
